Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorEike Stepper2015-07-18 09:19:35 +0000
committerGerrit Code Review @ Eclipse.org2017-01-17 10:38:39 +0000
commit9d3fc270ce09a88809b68a056ee7b6ace5eaf681 (patch)
treef12ed08358e8faf38e6eb24793ee535a632cb44a
parent09b55cc7202c39de03a85b6d0d5291424c66d7cb (diff)
downloadorg.eclipse.papyrus-9d3fc270ce09a88809b68a056ee7b6ace5eaf681.tar.gz
org.eclipse.papyrus-9d3fc270ce09a88809b68a056ee7b6ace5eaf681.tar.xz
org.eclipse.papyrus-9d3fc270ce09a88809b68a056ee7b6ace5eaf681.zip
Bug 472988: DiscoveryComponent.DISCOVERY_PAPYRUS_URI should be configurable
Change-Id: Ie154b04494c2016db8c92f79c5afafadfcd47c28 Signed-off-by: Eike Stepper <stepper@esc-net.de> Signed-off-by: Vincent Lorenzo <vincent.lorenzo@cea.fr>
-rw-r--r--plugins/infra/discovery/org.eclipse.papyrus.infra.discovery.ui/src/org/eclipse/papyrus/infra/discovery/ui/wizards/DiscoveryComponent.java12
1 files changed, 5 insertions, 7 deletions
diff --git a/plugins/infra/discovery/org.eclipse.papyrus.infra.discovery.ui/src/org/eclipse/papyrus/infra/discovery/ui/wizards/DiscoveryComponent.java b/plugins/infra/discovery/org.eclipse.papyrus.infra.discovery.ui/src/org/eclipse/papyrus/infra/discovery/ui/wizards/DiscoveryComponent.java
index b5861e9dbf7..9f0e3647880 100644
--- a/plugins/infra/discovery/org.eclipse.papyrus.infra.discovery.ui/src/org/eclipse/papyrus/infra/discovery/ui/wizards/DiscoveryComponent.java
+++ b/plugins/infra/discovery/org.eclipse.papyrus.infra.discovery.ui/src/org/eclipse/papyrus/infra/discovery/ui/wizards/DiscoveryComponent.java
@@ -32,13 +32,11 @@ import org.eclipse.ui.PlatformUI;
*/
public class DiscoveryComponent {
- /**
- * URI of the model where all extra component features to be installed are referenced.
- *
- * @noreference This field is not intended to be referenced by clients.
- */
- public static final String DISCOVERY_PAPYRUS_URI = "http://www.eclipse.org/modeling/mdt/papyrus/downloads/discovery/neon/papyrus-extra.xmi";
-
+ /**
+ * URI of the model where all extra component features to be installed are referenced. Can be set via the system property 'papyrus.discovery.uri'.
+ */
+ public static final String DISCOVERY_PAPYRUS_URI = System.getProperty("papyrus.discovery.uri", "http://www.eclipse.org/modeling/mdt/papyrus/downloads/discovery/neon/papyrus-extra.xmi"); //$NON-NLS-1$ //$NON-NLS-2$
+
public static final Object execute() {
final IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();

Back to the top